@@ -11,7 +11,7 @@ from gettextfile.view import FileView
 from views.login import LoginDialog
 from servers.model import TransifexLoginFailed
 from bookmarks.model import BookmarkListModel
-
+from views.about import About
 from PyQt4.QtGui import QFileDialog
 from files.model import LocalFileModel
 try:
@@ -82,6 +82,9 @@ class ServerView(CustomWindow):
                 username=username, password=password, remember=remember)
             if not accepted:
                 return None
+                
+    def about(self):
+        About(self).exec_()
 
     def __init__(self, model):
         CustomWindow.__init__(self,title="",
@@ -101,6 +104,10 @@ class ServerView(CustomWindow):
             self.tr("&Open local file"),
             self.fileOpen)
             
+        self.menuBar().addAction(
+            self.tr("&About"),
+            self.about)
+            
         if not d:
 #            self.close()
             return
